@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2018 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -19,8 +19,6 @@
 #ifndef PHP_GMP_H
 #define PHP_GMP_H
 
-#if HAVE_GMP
-
 #include <gmp.h>
 
 extern zend_module_entry gmp_module_entry;
@@ -56,12 +54,14 @@ ZEND_FUNCTION(gmp_rootrem);
 ZEND_FUNCTION(gmp_pow);
 ZEND_FUNCTION(gmp_powm);
 ZEND_FUNCTION(gmp_perfect_square);
+ZEND_FUNCTION(gmp_perfect_power);
 ZEND_FUNCTION(gmp_prob_prime);
 ZEND_FUNCTION(gmp_gcd);
 ZEND_FUNCTION(gmp_gcdext);
 ZEND_FUNCTION(gmp_invert);
 ZEND_FUNCTION(gmp_jacobi);
 ZEND_FUNCTION(gmp_legendre);
+ZEND_FUNCTION(gmp_kronecker);
 ZEND_FUNCTION(gmp_cmp);
 ZEND_FUNCTION(gmp_sign);
 ZEND_FUNCTION(gmp_and);
@@ -80,15 +80,8 @@ ZEND_FUNCTION(gmp_testbit);
 ZEND_FUNCTION(gmp_popcount);
 ZEND_FUNCTION(gmp_hamdist);
 ZEND_FUNCTION(gmp_nextprime);
-
-/* GMP and MPIR use different datatypes on different platforms */
-#ifdef PHP_WIN32
-typedef zend_long gmp_long;
-typedef zend_ulong gmp_ulong;
-#else
-typedef long gmp_long;
-typedef unsigned long gmp_ulong;
-#endif
+ZEND_FUNCTION(gmp_binomial);
+ZEND_FUNCTION(gmp_lcm);
 
 ZEND_BEGIN_MODULE_GLOBALS(gmp)
 	zend_bool rand_initialized;
@@ -101,18 +94,4 @@ ZEND_END_MODULE_GLOBALS(gmp)
 ZEND_TSRMLS_CACHE_EXTERN()
 #endif
 
-#else
-
-#define phpext_gmp_ptr NULL
-
-#endif
-
 #endif	/* PHP_GMP_H */
-
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- */
